# OlliePy - An alternative approach for evaluating ML models
> **OlliePy** is a python package which can help the data scientists in
> evaluating and analysing their machine learning experiments by
> utilising the power and structure of modern web applications. 
> The data scientist only needs to provide the data and any required 
> information and OlliePy will generate the rest.

### <br/>Get started by following the [**OlliePy** guide](https://ahmed-mohamed-sn.github.io/olliePy/)
